@@ -33,4 +33,7 @@ class DfkCli(click.MultiCommand):
 
 @click.command(cls=DfkCli, context_settings=CONTEXT_SETTINGS)
 def cli():
-    """🐳 dfk - Write once, run away!"""
\ No newline at end of file
+    """🐳 dfk - Write once, run away!"""
+
+if __name__ == '__main__':
+    cli()
\ No newline at end of file
