@@ -7,7 +7,7 @@ from dfk.cli import DfkCli
 
 @click.group("campaign")
 def cli():
-    """🎯 Faulty campaigns."""
+    """🎯 Injection campaigns."""
 
 
 @dfk.config.require_login
